# -*- coding: utf-8 -*-

# Copyright (C) 2010, 2011 Anaël Verrier <elghinn@free.fr>
# Copyright (C) 2014, 2020 kaliko <kaliko@azylum.org>

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, version 3 only.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from .sid import botcmd


class Plugin:
    """
    Simple Plugin object to derive from:

       * Exposes the bot object and its logger
       * Provides send helpers

    :param sid.sid.MUCBot bot: bot the plugin is load from
    """

    def __init__(self, bot):
        self.bot = bot
        self.log = bot.log.getChild(self.__class__.__name__)

    def send(self, dest, msg, mtype='chat'):
        """Send msg to dest

        :param str dest: Message recipient
        :param dict,str msg: Message to send (use dict for xhtml-im)

        .. note::
          if **msg** is a :py:obj:`dict` to provide xhmlt-im massages::

              msg = {
                  mbody: 'text',
                  mhtml: '<b>text</b>,  # optional'
              }
        """
        if isinstance(msg, str):
            msg = {'mbody': msg}
        msg.setdefault('mhtml', None)
        self.bot.send_message(mto=dest,
                              mtype=mtype,
                              **msg)

    def reply(self, rcv, msg):
        """Smart reply to message received.

        Replies ``msg`` in private or on the muc depending on ``rcv``

        :param rcv: The received message (slixmpp object)
        :param dict,str msg: The message to reply, refer to :py:obj:`sid.plugin.Plugin.send` for ``msg`` format
        """
        to = rcv['from']
        if rcv['type'] == 'groupchat':
            to = rcv['mucroom']
        self.send(to, msg, mtype=rcv['type'])

    def shutdown(self):
        pass
